@@ -175,15 +175,6 @@ test_that("Reset a dataset script", {
   expect_identical("iris" %in% offline_dataset_names, TRUE)
 })
 
-test_that("Citation info is correct", {
-  skip_if_no_retriever()
-  portal_citation <- rdataretriever::get_citation('portal')
-  expect_true(is.character(portal_citation))
-  expect_match(portal_citation[1],
-               "Citation:   S. K. Morgan Ernest, Thomas J. Valone, and James H. Brown. 2009. Long-term monitoring and experimental manipulation of a Chihuahuan Desert ecosystem near Portal, Arizona, USA. Ecology 90:1708.", 
-               fixed = TRUE)
-})
-
 test_that("Citation of scripts", {
   skip_if_no_retriever()
   portal_citation <- rdataretriever::get_script_citation('portal')
